#include <cmath>
#include <iomanip>
#include <iostream>
using namespace std;

inline double sqr(const double x)
    { return x*x; }

inline double lerp(const double val0, const double val1, const double t)
    { return (1.-t)*val0 + t*val1; }

struct Path
{
    int heights[4];
    int time;
    double times[4];
    int side;
    int timeIndex;
    double currentTime;
    double nextTime;
    int direction;
    
    friend istream& operator>>(istream& is, Path& path)
    {
        return is
            >> path.heights[0] >> path.heights[1]
            >> path.heights[2] >> path.heights[3]
            >> path.time;
    }
    bool valid() const
    {
        return time;
    }
    void compute(int id)
    {
        double distance = 0.;
        double dsts[4];
        for (int i=0; i<4; i++) {
            int h1 = heights[i];
            int h2 = heights[(i+1)%4];
            double base1 = (280-h1)*220./280.;
            double base2 = (280-h2)*220./280.;
            distance +=
                dsts[i] = sqrt(sqr(base1-base2)+sqr(base1+base2)+sqr(h1-h2));
        }
        for (int i=0; i<4; i++) {
            times[i] = time*(dsts[i]/distance);
        }
        side = id;
        timeIndex = 0;
        currentTime = 0.;
        nextTime = times[0];
        direction = id ? 3 : 1;
    }
    void advance()
    {
        currentTime = nextTime;
        timeIndex = (timeIndex+1)%4;
        side = (side+direction)%4;
        nextTime += times[timeIndex];
    }
};

int gcd(int A, int B)
{
    if (B > A) {
        int tmp = A;
        A = B;
        B = tmp;
    }
    int r = A / B;
    int m = A - r * B;
    while (m) {
        A = B;
        B = m;
        r = A / B;
        m = A - r * B;
    }
    return B;
}

double findDistance(
    const Path& P1,
    const Path& P2,
    const double startTime,
    const double endTime
)
{
    double sT1 = (startTime-P1.currentTime)/(P1.nextTime-P1.currentTime);
    double eT1 = (  endTime-P1.currentTime)/(P1.nextTime-P1.currentTime);
    double sT2 = (startTime-P2.currentTime)/(P2.nextTime-P2.currentTime);
    double eT2 = (  endTime-P2.currentTime)/(P2.nextTime-P2.currentTime);

    double scaleX = 220./280.;
    double scaleY = sqrt(sqr(220.)+sqr(280.0))/280.;

    double sH1 = P1.heights[P1.timeIndex];
    double eH1 = P1.heights[(P1.timeIndex+1)%4];
    double sH2 = P2.heights[P2.timeIndex];
    double eH2 = P2.heights[(P2.timeIndex+1)%4];
    
    double sX1 = lerp(sH1-280, eH1-280, sT1)*scaleX;
    double eX1 = lerp(280-sH1, 280-eH1, eT1)*scaleX;
    double sX2 = lerp(280-sH2, 280-eH2, sT2)*scaleX;
    double eX2 = lerp(sH2-280, eH2-280, eT2)*scaleX;

    double sY1 = lerp(sH1, eH1, sT1)*scaleY;
    double eY1 = lerp(sH1, eH1, eT1)*scaleY;
    double sY2 = lerp(sH2, eH2, sT2)*scaleY;
    double eY2 = lerp(sH2, eH2, eT2)*scaleY;
    
    double dX1 = eX1-sX1;
    double dY1 = eY1-sY1;
    double dX2 = eX2-sX2;
    double dY2 = eY2-sY2;
    
    //cout << startTime << "::" << endTime << endl;
    //cout << P1.currentTime << "::" << P1.nextTime << endl;
    //cout << P2.currentTime << "::" << P2.nextTime << endl;
    //cout << sH1 << "->" << eH1 << ", " << sH2 << "->" << eH2 << endl;
    
    //cout << "1: (" << sX1 << ", " << sY1 << ") -> (" << eX1 << ", " << eY1 << ")" << endl;
    //cout << "2: (" << sX2 << ", " << sY2 << ") -> (" << eX2 << ", " << eY2 << ")" << endl;

    dX1 -= dX2;
    dY1 -= dY2;
    
    double dXi = sX2-sX1;
    double dYi = sY2-sY1;
    
    double D = fabs((dX1*dYi-dY1*dXi))/sqrt(sqr(dX1)+sqr(dY1)); // om nom nom
    
    //cout << fixed << setprecision(3) << D << endl;
    return D;
}


int main(int argc, char* argv[])
{
    Path G1, G2;
    while (cin >> G1) {
        if (!G1.valid()) break;
        cin >> G2;
        G1.compute(0);
        G2.compute(1);
        int tests = 4*(G1.time+G2.time)/gcd(G1.time, G2.time);
        double distance = 10e10;
        double startTime = 0.;
        for (int i=0; i<=tests; i++) {
            if (G1.nextTime < G2.nextTime) {
                if (G1.side == G2.side) {
                    distance = min(distance, findDistance(G1, G2, startTime, G1.nextTime));
                }
                G1.advance();
                if (G1.side == G2.side) startTime = G1.currentTime;
            } else {
                if (G1.side == G2.side) {
                    distance = min(distance, findDistance(G1, G2, startTime, G2.nextTime));
                }
                G2.advance();
                if (G1.side == G2.side) startTime = G2.currentTime;
            }
        }
        cout << fixed << setprecision(3) << distance << endl;
    }
    return 0;
}